# path去重
export PATH=$(echo $PATH | tr ':' '\n' | cat -n | sort -k2,2 -k1,1n | uniq -f1 | sort -k1,1n | cut -f2- | tr '\n' ':')

function targz() {
	tar -zcvf "${1}".tgz "$1"
	ll -h ${1}.tgz
}
function untar() {
  tar -zxvf "$1"
}
alias sync_config_file='wget https://git.tianyunperfect.cn/tianyunperfect/sync/raw/master/sh_config.sh -O ~/.sh_config.sh && source ~/.sh_config.sh'
# 快捷命令
## 未分类
alias ll='ls -alh --time-style="+%Y-%m-%d %H:%I:%S"'
#du -sh * 2>/dev/null | sort -hr
alias du-sh='du -sh * 2>/dev/null | sort -hr'
alias du-sh10='du -sh * 2>/dev/null | sort -hr | head -n 10'
alias sourcevenv='source venv/bin/activate'

alias weather='curl wttr.in/beijing'
alias dust1='dust -d 1'

function gittagpush() {
	if [ $# -ne 2 ]; then
		echo "需要两个参数: <变量1> <变量2>"
		return 1
	fi

	git tag -a $1 -m "$2"
	git push origin $1
}
alias gittags='git --no-pager tag -l -n'

function reloadrc() {
	if [ -n "$ZSH_VERSION" ]; then
		echo "正在使用zsh"
		source ~/.zshrc
	elif [ -n "$BASH_VERSION" ]; then
		echo "正在使用bash"
		source ~/.bashrc
	else
		echo "无法确定当前 Shell 类型"
	fi
}
function k8s-get-all-namespace(){
	kubectl get namespace
}
## k8s
function k8s-get-default-namespace() {
	kubectl config view | grep namespace
}
function k8s-set-default-namespace() {
	k8s-get-all-namespace
	kubectl config set-context --current --namespace="$1"
}
function k8s-getpod() {
	k8s-get-all-namespace
	# 如果有参数，则过滤
	if [ ! -z "$1" ]; then
		kubectl get pods -o wide | grep "$1"
	else
		kubectl get pods -o wide
	fi
}
alias k8s-descpods='kubectl describe pods'
function k8s-getlog() {
	k8s-get-all-namespace
	podName=$(kubectl get pods -o wide | grep "${1}" | awk '{print $1}')
	kubectl logs --tail=300 -f "${podName}"
}
function k8s-getlogbase() {
	k8s-get-all-namespace
	podName=$(kubectl get pods -o wide | grep "${1}" | awk '{print $1}')
	kubectl logs -c base-jre --tail=300 -f "${podName}"
}
alias k8s-delpod='kubectl delete pod ${1} --force'
function k8s-inpod() {
	k8s-get-all-namespace
	podName=$(kubectl get pods -o wide | grep "${1}" | awk '{print $1}')
	kubectl exec -it "${podName}" -- /bin/bash
}

alias k8s-topnodes='kubectl top node ${1}'

alias k8s-toppods='kubectl top pod ${1}'

alias k8s-getsvc='kubectl get svc'
alias k8s-descsvc='kubectl describe svc'

alias k8s-deldeployment='kubectl delete deployment'
alias k8s-getdeployment='kubectl get deployment'
alias k8s-descdeployment='kubectl describe deployment'
alias k8s-getdeploymentgrep='kubectl get deployment | grep'

alias k8s-getingress='kubectl get ingress'
alias k8s-descingress='kubectl describe ingress'
alias k8s-getingressgrep='kubectl get ingress | grep'

## docker
alias docker-rm-all-image='docker rmi $(docker images -q)'
alias docker-rm-all-docker='docker rm $(docker ps -a -q)'
alias docker-show-image-prune='docker image ls -f dangling=true'
alias docker-image-prune='docker image prune -a'
alias dkstats='docker stats'
alias dkps='docker ps --format "table {{.ID}}\t{{.Names}}\t{{.Ports}}"'
alias dkpsa='docker ps -a --format "table {{.ID}}\t{{.Names}}\t{{.Ports}}"'
alias dkrm='docker rm -f $1'
alias dkrmi='docker rmi -f $1'
alias dkimage='docker images --format "table {{.ID}}\t{{.Repository}}\t{{.Tag}}\t{{.Size}}"'
alias dkip='docker inspect --format="{{.Name}} - {{range .NetworkSettings.Networks}}{{.IPAddress}}{{end}}" $(docker ps -aq)'
function dkin() {
	docker exec -it "$1" bash
}
function dkinsh() {
	docker exec -it $1 sh
}
alias dklog='docker logs -n 300 -f $1'
alias dkinspect='docker inspect $1'

## go
alias gobuildwinexe='GOOS=windows GOARCH=amd64 go build -o $1.exe $1.go'
alias gobuildlinuxexe='GOOS=linux GOARCH=amd64 go build -o $1 $1.go'
alias gobuildmacexe='GOOS=darwin GOARCH=amd64 go build -o $1 $1.go'

## version
alias pythonversion='python --version'
alias javaversion='java -version'
alias nodeversion='node -v'
alias centosversion='cat /etc/os-release'
alias ubuntuversion='cat /etc/lsb-release'
alias goversion='go version'

## ip查看
alias ipremote='curl cip.cc'
function iplocal() {
	# 如果是mac 过滤 en0,如果是linux 过滤 eth0
	if [[ "$OSTYPE" == "darwin"* ]]; then
		ifconfig en0 | grep inet | grep -v inet6
	else
		ifconfig eth0 | grep inet | grep -v inet6
	fi
}

## 进程相关
alias psgrep='ps aux | grep -v grep | grep'
alias killport='kill -9 $(lsof -t -i:$1)'
alias ps-mem-top6='ps aux --sort=-%mem | awk '\''{print $2, $11, $4, $6/1024 "MB"}'\'' | head -n 6'

# node
alias npminstall='npm install -g --registry=https://registry.npmmirror.com '

# python
alias pipinstall='pip install $1 -i http://mirrors.aliyun.com/pypi/simple/ --trusted-host mirrors.aliyun.com'

# 文件查找相关
function findByName() {
	local pattern=$1
	find . -name "*$pattern*"
}
function findByContent() {
	local pattern=$2
	local dir=$1
	find $dir -type f -exec grep -l "$pattern" {} +
}

# 备份
function tar_back() {
	time=$(date "+%Y-%m-%d_%H_%M_%S")
	tar -zcvf "${1}".${time}.tgz "$1"
	ll -h ${1}.${time}.tgz
}

pid-cmd-centos() {
	sudo ls -l /proc/$1/cwd | awk '{print $11}'
	sudo cat /proc/$1/cmdline
	echo ''
}
pid-cmd-ubuntu() {
	ls -l /proc/"$1"/cwd | awk '{print $11}'
	tr '\0' ' ' </proc/"$1"/cmdline
	echo ""
}

function echo-arthas-install() {
	echo '
    # 判断是否存在 ~/arthas-boot.jar，如果不存在则下载
    if [ ! -f ~/arthas-boot.jar ]; then
        ( cd ~ && curl -O https://arthas.aliyun.com/arthas-boot.jar )
    fi

    # 判断是否在k8s里面
    if [[ ! -z "$KUBERNETES_SERVICE_HOST" && ! -z "$KUBERNETES_SERVICE_PORT" ]]; then
        echo "Running in Kubernetes environment"
        java -jar ~/arthas-boot.jar 1 --options json-format=true
    else
        echo "Not running in Kubernetes environment"
        java -jar ~/arthas-boot.jar --options json-format=true
    fi
    '
}
alias cparthas='echo-arthas-install | pbcopy'

function curl-form() {
	curl -d "$2" "$1"
}

function watch-cpudiskmemory() {
	watch -n 1 '
    echo "===CPU占用摘要："
    top -bn 1 -i -c | grep Cpu

    echo "
    ===内存占用摘要："
    free -h

    echo "
    ===磁盘占用摘要："
    df -h /'
}
#123
function vimrc() {
	if [[ "$SHELL" =~ "zsh" ]]; then
		code ~/.zshrc
	else
		code ~/.bashrc
	fi
}

merge_video_audio() {
	if [ "$#" -ne 3 ]; then
		echo "错误：参数数量不正确！"
		echo "用法：merge_video_audio video.mp4 audio.mp3 output.mp4"
		return 1
	fi

	ffmpeg -i "$1" -i "$2" -c:v copy -c:a copy "$3"
}

rm-all() {
	find . -name $1 | xargs -I {} rm -rf {}
}

### mysql
function echo-mysql-tables() {
	echo 'SELECT table_name, table_comment FROM information_schema.tables WHERE table_schema = DATABASE();'
}
function echo-mysql-table-size() {
	echo 'select table_name,concat(round(sum(DATA_LENGTH/1024/1024),2),"MB") as data from information_schema.TABLES where  table_schema =(SELECT DATABASE()) group by table_name;'
}
function echo-mysql-db-size() {
	echo 'select table_schema,concat(round(sum(DATA_LENGTH/1024/1024),2),"MB") as data from information_schema.TABLES  where table_schema not in ("information_schema","mysql","performance_schema","sys")  group by table_schema;'
}

function echo-npm() {
	echo '
                   npm i webpack				 # 在module文件中安装
                   npm i webpack -S 		# --save     常用，添加到package
                   npm i webpack -D 		# --save-dev
                   npm i webpack -g 	 --registry=https://registry.npmmirror.com	 # 全局
                   npm un webpack -g

                   yarn add react
                   yarn remove react
                   yarn global add umi
                   '
}

concat_params() {
	# 获取传入的参数个数
	num_params=$#

	# 判断参数个数是否大于等于1
	if [ $num_params -ge 1 ]; then
		# 使用循环遍历参数，并拼接在一起
		concat_str="$1"
		for ((i = 2; i <= $num_params; i++)); do
			concat_str+="%20${!i}"
		done

		# 打印拼接后的字符串
		echo "$concat_str"
	else
		echo "没有传入参数"
	fi
}
function url_encode() {
	echo "$1" | sed 's/ /%20/g'
}
function bing() {
	## 如果是windows系统，则使用start，否则使用open，后面的参数可以有多个空格
	if [[ "$OSTYPE" == "msys"* ]]; then
		search_query=$(concat_params "$@")
		start "https://www.bing.com/search?q=$search_query"
	else
		search_query=""
		for query in "$@"; do
			search_query+=" $query"
		done
		search_query=$(url_encode "$search_query")
		open "https://www.bing.com/search?q=${search_query}"
	fi
}

function mvn_clean_package() {
	mvn clean package -Dmaven.test.skip=true
}

## ska快捷
function ska_push_dev() {
	skaffold run -p dev --tail
}

function mvn_push_dev() {
	mvn_clean_package
	ska_push_dev
}
function mvn_push_test() {
	mvn_clean_package
	skaffold build -p test -n aimptest
}
function mvn_clean_deploy() {
	mvn clean deploy -Dmaven.test.skip=true
}

function show_all_local_ip() {
	arp -a
}

alias nodels='fnm ls'
alias nodeuse='fnm use'
alias nodedefault='fnm default'
alias nodeinstall='fnm install'
alias nodelsremote='fnm ls-remote'
alias nodeuninstall='fnm uninstall'

alias catnodeversion='node --version > .node-version'

alias yarnglobaladd='yarn global add'
alias yarnglobalremove='yarn global remove'
alias yarnadd='yarn add'
alias yarnremove='yarn remove'
alias yarninstall='yarn install'

function echosync() {
	echo '
source <(curl -s https://git.tianyunperfect.cn/tianyunperfect/sync/raw/master/sh_config.sh)
'
}

alias settitle='wezterm cli set-tab-title '

function btm_linux() {
	if [ ! -f "$HOME/btm" ]; then
		wget https://tianyunperfect1.oss-cn-beijing.aliyuncs.com/20/2024/btm/btm -O ~/btm
		chmod +x ~/btm
	fi

	~/btm --process_memory_as_value
}

# watch 优化
alias watch_alias='watch '
# 函数，每隔2秒执行一次参数命令
function watch_func() {
	while true; do
		clear
		"$@"
		sleep 2
	done
}

alias gpu_nvidia='nvidia-smi'
alias gpu_amd='rocm-smi --showpids -u  -P'

alias iptables_show_all='iptables -t nat -L -n'

# docker-compose up ,如果有参数，则使用-f 文件
function docker_compose_up() {
	if [ $# -eq 0 ]; then
		docker-compose up -d
		return
	fi
	docker-compose -f "$1" up -d
}
# 同理 docker-compose down
function docker_compose_down() {
	if [ $# -eq 0 ]; then
		docker-compose down
		return
	fi
	docker-compose -f "$1" down
}

# Ubuntu/Debian: sudo apt-get install moreutils
# CentOS/RHEL: sudo yum install moreutils
# macOS: brew install moreutils
# 用法  tail -f abc.log | pt
alias pt="ts '[%Y-%m-%d %H:%M:%S]'"
alias rcp='rsync -a --delete '


# 函数：生成指定大小的文件 generate_file 2 M "logfile.log"
generate_file() {
    local size=$1
    local unit=$2
    local filename=${3:-"generated_file.bin"}  # 默认文件名为generated_file.bin

    # 检查单位是否正确
    case $unit in
        "B"|"b")
            bs=1
            ;;
        "K"|"k")
            bs=1K
            ;;
        "M"|"m")
            bs=1M
            ;;
        "G"|"g")
            bs=1G
            ;;
        *)
            echo "错误：不支持的单位。请使用 B, K, M, 或 G。"
            return 1
            ;;
    esac

    # 使用dd命令生成文件
    dd if=/dev/urandom of="$filename" bs=$bs count=$size status=none
}
